Learn R Programming

RSurvey (version 0.4.5)

RSurvey-package: Analysis of Spatially Distributed Data

Description

This package is a processing program for spatially distributed data. The application is capable of error corrections and data visualization. A graphical user interface (GUI) is provided.

Arguments

Details

ll{ Package: RSurvey Type: Package Version: 0.4.5 Date: 2009-04-03 License: GPL version 2 or newer. }

Examples

Run this code
library(RSurvey)

Run the code above in your browser using DataLab