Learn R Programming

RSurvey (version 0.4.5)

axesLimits: Set Limits on Raster Data

Description

A GUI for setting plotting limits associated with raster data.

Usage

axesLimits(tt2 = NULL, old = list())

Arguments

tt2
a Tk toplevel widget.
old
the current plotting limits, see Value section.

Value

  • A list containing 6 components:
  • z.minthe minimum z-axis value, default NA.
  • z.min.autothe default value for the minimum z-axis, default TRUE.
  • z.maxthe maximum z-axis value, default NA.
  • z.max.autothe default value for the maximum z-axis, default TRUE.
  • z.levthe number of contour levels, default NA.
  • z.lev.autothe default value for the number of contour levels, default TRUE.

Examples

Run this code
axesLimits()

Run the code above in your browser using DataLab