Learn R Programming

RSurvey (version 0.4.5)

getFile: Select a File to Open or Save.

Description

A pop up a dialog box for the user to select a file to open or save.

Usage

getFile(cmd = "Open", exts = NULL, directory = NULL, file = NULL, titleStr = cmd)

Arguments

cmd
determines if an "Open" or "Save As" file management pop up dialog box is implemented.
exts
an array of default file extensions.
directory
specifies that the files in directory should be displayed when the dialog pops up.
file
either a character string naming a file or a connection.
titleStr
a character string to display as the title of the dialog box.

Value

  • A list containing 4 components:
  • dirthe directory containing the file.
  • paththe file path
  • namethe file name
  • extthe file extension

Examples

Run this code
getFile()

Run the code above in your browser using DataLab