Learn R Programming

RSurvey (version 0.4.5)

keyEvent: Content Control within Tk Entry Widgets

Description

Controls the character string content within a Tk entry widget.

Usage

keyEvent(ent.typ, ent.str = "", rm.data = FALSE)

Arguments

ent.typ
the entry type
ent.str
the entry value
rm.data
a logical; if TRUE the existing processed data is removed.

Value

  • A character string with strict adherence to the entry type.

Details

The entry types include: real, second, integer, hour, minute, and date. If rm.data is TRUE then both the data.mod and data.tin components of srvy.dat are removed.

See Also

tkentry

Examples

Run this code
keyEvent("date", "07/12/1971")
## [1] "07/12/1971"

keyEvent("date", "7/2/19uq")
## [1] "7/2/19"

keyEvent("hour", "13")
## [1] "13"

keyEvent("hour", "25")
## [1] "23"

Run the code above in your browser using DataLab