Learn R Programming

RSurvey (version 0.4.5)

minorTics: Place Minor Tick Marks on Plot Axis

Description

Adds minor axis tic marks to the active plot.

Usage

minorTics(side, loc.tics = NULL)

Arguments

side
an array of integers specifying the plot sides for the axis to be drawn.
loc.tics
the location of the major tic marks.

Details

The plot sides are designated as: 1 = below, 2 = left, 3 = above, and 4 = right.

See Also

axis

Examples

Run this code
plot(1:10)
minorTics(1)
minorTics(2, loc.tics=4:8)
minorTics(3, c(4, 6, 8))

Run the code above in your browser using DataLab