Learn R Programming

RSurvey (version 0.4.5)

plotPoints: Plot Spatial Locations and Corresponding State Variable

Description

Draw a scatter plot of spatial coordinates (x,y) and their associated state variable (z) values. A key showing how the colors map to state variable values is shown to the right of the plot.

Usage

plotPoints()

Arguments

See Also

plot

Examples

Run this code
data(confluence)
plotPoints()

Run the code above in your browser using DataLab