Learn R Programming

RSurvey (version 0.4.5)

plotSurface2d: Plot 2D Interpolated Surface

Description

A filled contour plot showing the distributed spatial data is drawn. A key showing how the colors map to state variable values is shown to the right of the plot.

Usage

plotSurface2d(const.poly = FALSE)

Arguments

const.poly
a logical; if TRUE the user is required to interactively construct the spatial domain within the active plot.

See Also

mba.surf, filled.contour

Examples

Run this code
data(confluence)
plotSurface2d()

Run the code above in your browser using DataLab