the raster field of interest, see the type component in tran.dat.
velPlot
a logical; if TRUE velocity raster data is plotted.
flow
the velocity component types to use where "magnitude" is the principle direction of flow and "longTran" is the longitudinal and transverse directions.
Details
If the rasterField argument is missing a profile is plotted along the transect.
The horizontal axis is representative of the distance between transect vertices and
the vertical axis the distance from the vertex origin, v.origin, positive upward.
The profile along a transect is by default based on the interpolated surface, data.tin.
If the data.tin component of srvy.dat is NULL the function will attempt to
access imported profile data in prof.