Learn R Programming

RSurvey (version 0.4.5)

restoreSession: Restore Session from Source Code Files

Description

This function restores local objects within the current Rsession.

Usage

restoreSession(path, save.objs, fun.call)

Arguments

path
a full path name; if missing a folder browser pop up dialog box is implemented.
save.objs
the name of local objects to preserve during the recompiling process.
fun.call
the name of the function to call after restoring the session (optional).

Value

  • An updated Rsession compiled from .R source code files located in path and its recursive directories.

See Also

source

Examples

Run this code
restoreSession()

Run the code above in your browser using DataLab