Learn R Programming

RSurvey (version 0.4.5)

srvy: Main Tcl/Tk Graphical User Interface

Description

This function activates the main graphical user interface (GUI) for RSurvey.

Usage

srvy()

Arguments

Value

  • The following components within srvy.dat are set: sd, ed, sh, sm, em, ss, min.x, max.x, min.y, max.y, min.z, max.z, off.z, off.t.

Details

Most functions within RSurvey are accessible within this GUI. The text file format of survey data is described in readFile. The text file representation of a polygon is of the following format: x1 y1 x2 y2 ... x1 y1 x2 y2 ... The hole flag is either 1 to indicate a hole, or 0 for a regular contour. See read.polyfile within the gpclib package for details.

Examples

Run this code
srvy()

Run the code above in your browser using DataLab