Learn R Programming

RSurvey (version 0.4.5)

srvy.config: Window and Plotting Parameters

Description

A GUI used to define window geometry and universal plotting parameters.

Usage

srvy.config(tt1 = NULL)

Arguments

tt1
a Tk toplevel widget.

Value

  • The following components within srvy.dat are set: n.levels, win.windth, yx.ratio, zx.ratio, date.fmt.

Details

The output date/time format is based on character representations described in strptime, for example "%d/%m/%Y %H:%M:%OS".

Examples

Run this code
srvy.config()

Run the code above in your browser using DataLab