either a character string naming a file or a connection.
Value
The output of srvy.export is dependent on the file type chosen within the file
management pop up dialog box. Choosing a file type of *.txt writes the contents
of data.mod to a file, whereas a choice of *.tin writes the contents of
data.tin to a file.