Learn R Programming

RSurvey (version 0.4.5)

srvy.process: Process Survey Data

Description

This function limits the spatial and temporal domains of raw data and corrects for erroneous state variable measurements.

Usage

srvy.process(const.tin = FALSE)

Arguments

const.tin
a logical; if TRUE interpolation is used to construct a surface map of the state variable.

Value

  • A data frame data.mod and list data.tin are stored within srvy.dat.

Details

Erroneous state variable measurements are identified by calculating the change in z over the change in time for sequential data records. Those gradients exceeding a user defined tolerance, grad.tol (see srvy.dat), are identified as erroneous measurements. After excluding these measurements the process is repeated until all gradients are less than the user specified tolerance. An exception to the tolerance constraint is made for sequential records whose time difference is greater than a specified time gap, time.gap (see srvy.dat).

See Also

mba.surf

Examples

Run this code
data(confluence)
srvy.process(const.tin = TRUE)

Run the code above in your browser using DataLab