Learn R Programming

RSurvey (version 0.4.5)

srvy.vars: Data Variables

Description

A GUI for identifying temporal and spatial variables associated with survey data.

Usage

srvy.vars(cols, vars, tt1 = NULL)

Arguments

cols
those components within srvy.dat corresponding to temporal and spatial data, a concatenation of column type and units.
vars
the components corresponding to data/time, x, y, and z data.
tt1
a Tk toplevel widget.

Details

The vars component is updated in srvy.dat.

Examples

Run this code
data(confluence)
srvy.vars(srvy.dat("cols"), srvy.dat("vars"))

Run the code above in your browser using DataLab