Learn R Programming

RSurvey (version 0.4.5)

tran.spatial: Spatial Fields for Raster Data

Description

Identify raster fields corresponding to spatial coordinates.

Usage

tran.spatial(rasterFields, spatialFields = NULL, tt2 = NULL)

Arguments

rasterFields
an array giving all raster fields.
spatialFields
current raster fields corresponding to the spatial coordinates (x,y).
tt2
a Tk toplevel widget.

Value

  • A character array containing field names associated with the local x-axis [1] and local z-axis [2] coordinates.

Examples

Run this code
tran.spatial(c("X (m)", "Z (m)", "T (degC"), c("X (m)", "Z (m)"))

Run the code above in your browser using DataLab