Learn R Programming

RSurvey (version 0.4.5)

tran.velocity: Velocity Components for Raster Data

Description

A GUI for identifying raster fields corresponding to velocity components.

Usage

tran.velocity(rasterFields, velocityFields = NULL, tt2 = NULL)

Arguments

rasterFields
an array containing all raster field names.
velocityFields
current raster fields corresponding to the x, y, z, and principle velocity components.
tt2
a Tk toplevel widget.

Value

  • A character array of field names associated with velocity components in the x [1], y [2], z [3], and principle [4] directions.

Examples

Run this code
tran.velocity(c("VelE (m/s)", "VelN (m/s)", "VelU (m/s)", "VelM (m/s)"))

Run the code above in your browser using DataLab