confluence: Sample Project
Description
A sample RSurvey project containing list objects srvy.dat
and tran.dat.source
The survey data was collected within the San Joaquin River Basin, CA, USA,
at the confluence of the Merced and San Joaquin river in July, 2007.Examples
Run this codedata(confluence)
summary(srvy.dat())
summary(tran.dat())
Run the code above in your browser using DataLab