Controls the character string content within a Tk entry widget.
Usage
keyEvent(ent.typ, ent.str = "", rm.data = FALSE)
Arguments
ent.typ
the entry type
ent.str
the entry value
rm.data
a logical; if TRUE the existing processed data is removed.
Value
A character string with strict adherence to the entry type.
Details
The entry types include: real, second, integer, hour,
minute, and date. If rm.data is TRUE
then both the data.mod and data.tin components of srvy.dat
are removed.