A filled contour plot showing the distributed spatial data is drawn.
A key showing how the colors map to state variable values is shown to the right of the plot.
Usage
plotSurface2d(const.poly = FALSE)
Arguments
const.poly
a logical; if TRUE the user is required to interactively construct the spatial domain within the active plot.