plotSurface3d: Plot 3D Interpolated Surface using OpenGL
Description
A three-dimensional (3D) surface plot of the processed survey data is drawn.
Usage
plotSurface3d()
Arguments
Details
The interpolated survey data is rendered using rgl, a 3D
visualization device system (OpenGL) for R.
The mouse is used for interactive viewpoint navigation where
the left, right, and center mouse buttons rotate the scene, rotate the scene around
the x-axis, and zooms the display, respectively.