Rdocumentation
powered by
Learn R Programming
RSurvey (version 0.4.5)
readFile: Data Input
Description
Reads a file in table format.
Usage
readFile(file, fields = TRUE, units = TRUE)
Arguments
file
either a character string naming a file or a connection.
fields
a logical value indicating whether the file contains the names of the variables as its first line.
units
a logical value indicating whether the file contains the units of the variables as its second line.